@@ -9,7 +9,7 @@ from flask import Flask, Response
 from flask import request, current_app, stream_with_context
 
 DEBUG = True
-TERMINATOR = '\r\n'
+TERMINATOR = '\n'
 
 GOURD_HTTP_DEFAULT_HOST = '127.0.0.1'
 GOURD_HTTP_DEFAULT_PORT = 5505
